@@ -3,12 +3,12 @@ compile_error!("One of the features `pio` or `native` must be selected.");
 
 // Note that the feature `native` must come before `pio`. These features are really
 // mutually exclusive but that would require that all dependencies specify the same
-// feature so instead we prefer the `native` feature over `pio` so that if one package
-// specifies it, this overrides the `pio` feature for all other dependencies too. 
+// feature so instead we prefer (for now) the `pio` feature over `native` so that if one package
+// specifies it, this overrides the `pio` feature for all other dependencies too.
 // See https://doc.rust-lang.org/cargo/reference/features.html#mutually-exclusive-features.
 #[cfg(any(feature = "pio", feature = "native"))]
-#[cfg_attr(feature = "native", path = "build_native.rs")]
-#[cfg_attr(all(feature = "pio", not(feature = "native")), path = "build_pio.rs")]
+#[cfg_attr(feature = "pio", path = "build_pio.rs")]
+#[cfg_attr(all(feature = "native", not(feature = "pio")), path = "build_native.rs")]
 mod build_impl;
 
 fn main() -> anyhow::Result<()> {
